require 'pathname'

ROOT_DIR = Pathname.new(File.dirname(__FILE__) + "/../").realpath.to_s

worker_processes 4
working_directory ROOT_DIR

# Do not preload app to save the memory - if set to true see https://raw.githubusercontent.com/defunkt/unicorn/master/examples/unicorn.conf.rb
preload_app false

# Restart any workers that haven't responded in xx seconds
timeout 500

# Listen on a Unix data socket
listen ROOT_DIR + '/tmp/sockets/unicorn.sock', :backlog => 2048, tcp_nopush: false
pid ROOT_DIR + '/tmp/pids/unicorn.pid'

stderr_path ROOT_DIR + "/log/unicorn.stderr.log"
stdout_path ROOT_DIR + "/log/unicorn.stdout.log"

# http://www.rubyenterpriseedition.com/faq.html#adapt_apps_for_cow
if GC.respond_to?(:copy_on_write_friendly=)
  GC.copy_on_write_friendly = true
end

# Enable this flag to have unicorn test client connections by writing the
# beginning of the HTTP headers before calling the application.  This
# prevents calling the application for connections that have disconnected
# while queued.  This is only guaranteed to detect clients on the same
# host unicorn runs on, and unlikely to detect disconnects even on a
# fast LAN.
check_client_connection false

# local variable to guard against running a hook multiple times
run_once = true

before_fork do |server, worker|
  # The following is only recommended for memory/DB-constrained
  # installations.  It is not needed if your system can house
  # twice as many worker_processes as you have configured.
  #
  # This allows a new master process to incrementally
  # phase out the old master process with SIGTTOU to avoid a
  # thundering herd (especially in the "preload_app false" case)
  # when doing a transparent upgrade.  The last worker spawned
  # will then kill off the old master process with a SIGQUIT.
  old_pid = "#{server.config[:pid]}.oldbin"
  if File.exists?(old_pid) && server.pid != old_pid
    begin
      sig = (worker.nr + 1) >= server.worker_processes ? :QUIT : :TTOU
      Process.kill(sig, File.read(old_pid).to_i)
    rescue Errno::ENOENT, Errno::ESRCH
      # someone else did our job for us
    end
  end
end

